@@ -40,6 +40,7 @@ from octavia.common import constants as consts
 from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.common import validate
+from octavia.db import api as db_api
 from octavia.db import models
 
 CONF = cfg.CONF
@@ -364,8 +365,7 @@ class Repositories(object):
                                  provisioning_status=lb_prov_status)
         return success
 
-    def check_quota_met(self, session, lock_session, _class, project_id,
-                        count=1):
+    def check_quota_met(self, session: Session, _class, project_id, count=1):
         """Checks and updates object quotas.
 
         This method makes sure the project has available quota
@@ -373,7 +373,6 @@ class Repositories(object):
         new ussage.
 
         :param session: Context database session
-        :param lock_session: Locking database session (autocommit=False)
         :param _class: Data model object requesting quota
         :param project_id: Project ID requesting quota
         :param count: Number of objects we're going to create (default=1)
@@ -390,19 +389,14 @@ class Repositories(object):
         if not project_id:
             raise exceptions.MissingProjectID()
 
-        quotas = self.quotas.get(session, project_id=project_id)
-        if not quotas:
-            # Make sure we have a record to lock
-            self.quotas.update(
-                session,
-                project_id,
-                quota={})
+        self.quotas.ensure_project_exists(project_id)
+
         # Lock the project record in the database to block other quota checks
         #
         # Note: You cannot just use the current count as the in-use
         # value as we don't want to lock the whole resource table
         try:
-            quotas = (lock_session.query(models.Quotas)
+            quotas = (session.query(models.Quotas)
                       .filter_by(project_id=project_id)
                       .populate_existing()
                       .with_for_update()
@@ -1244,23 +1238,22 @@ class AmphoraRepository(BaseRepository):
         :param amphora_id: The amphora id to list the load balancers from
         :returns: [octavia.common.data_model]
         """
-        with session.begin():
-            db_lb = (
-                # Get LB records
-                session.query(models.LoadBalancer)
-                # Joined to amphora records
-                .filter(models.LoadBalancer.id ==
-                        models.Amphora.load_balancer_id)
-                # For just this amphora
-                .filter(models.Amphora.id == amphora_id)
-                # Where the amphora is not DELETED
-                .filter(models.Amphora.status != consts.DELETED)
-                # And the LB is also not DELETED
-                .filter(models.LoadBalancer.provisioning_status !=
-                        consts.DELETED)).first()
-            if db_lb:
-                return db_lb.to_data_model()
-            return None
+        db_lb = (
+            # Get LB records
+            session.query(models.LoadBalancer)
+            # Joined to amphora records
+            .filter(models.LoadBalancer.id ==
+                    models.Amphora.load_balancer_id)
+            # For just this amphora
+            .filter(models.Amphora.id == amphora_id)
+            # Where the amphora is not DELETED
+            .filter(models.Amphora.status != consts.DELETED)
+            # And the LB is also not DELETED
+            .filter(models.LoadBalancer.provisioning_status !=
+                    consts.DELETED)).first()
+        if db_lb:
+            return db_lb.to_data_model()
+        return None
 
     def get_cert_expiring_amphora(self, session):
         """Retrieves an amphora whose cert is close to expiring..
@@ -1884,11 +1877,6 @@ class L7PolicyRepository(BaseRepository):
 class QuotasRepository(BaseRepository):
     model_class = models.Quotas
 
-    # Since this is for the initial quota record creation it locks the table
-    # which can lead to recoverable deadlocks. Thus we use the deadlock
-    # retry wrapper here. This may not be appropriate for other sessions
-    # and or queries. Use with caution.
-    @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
     def update(self, session, project_id, **model_kwargs):
         kwargs_quota = model_kwargs['quota']
         quotas = (
@@ -1905,6 +1893,19 @@ class QuotasRepository(BaseRepository):
         session.flush()
         return self.get(session, project_id=project_id)
 
+    # Since this is for the initial quota record creation it locks the table
+    # which can lead to recoverable deadlocks. Thus we use the deadlock
+    # retry wrapper here. This may not be appropriate for other sessions
+    # and or queries. Use with caution.
+    @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
+    def ensure_project_exists(self, project_id):
+        with db_api.session().begin() as session:
+            quotas = self.get(session, project_id=project_id)
+            if not quotas:
+                # Make sure we have a record to lock
+                self.update(session, project_id, quota={})
+            session.commit()
+
     def delete(self, session, project_id):
         quotas = (
             session.query(self.model_class)
